
API Documentation
=================

.. automodule:: tendril.utils.www
    :members:
    :undoc-members:
    :show-inheritance:

WWW Access Backends
-------------------

.. toctree::

   tendril.utils.www.bare
   tendril.utils.www.req
   tendril.utils.www.soap

Other WWW Utilities and Backend Helpers
---------------------------------------

.. toctree::

   tendril.utils.www.helpers
   tendril.utils.www.caching
   tendril.utils.www.redirectcache
   tendril.utils.www.status

Related Configuration Options
-----------------------------

.. toctree::

   tendril.config.www
